library(readxl)

excelFileName<-"./data/Survey.xlsx"
sheetName<-"Sheet1"
tabstexcel<-read_excel(excelFileName, sheetName)

getNoOfStudents<-function(){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(NROW(tabstdfr[["no"]])-1))  
}


getNoOfStudentsByGroup<-function(groupNo){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(NROW(tabstdfr[["no"]])-1))  
}


getNoOfStudentsByGroupByGender<-function(groupNo, gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$sex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(NROW(tabstdfr[["no"]])-1))  
}

getAvgAgeStudentsByGroup<-function(groupNo){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(mean(tabstdfr[["age"]],na.rm=TRUE)))  
}

getAvgAgeStudentsByGroupByGender<-function(groupNo, gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$sex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  age<-mean(tabstdfr[["age"]],na.rm=TRUE)
  return(if(!is.nan(age)) {as.numeric(age)} else {0})  
}

getMinAgeStudentsByGroup<-function(groupNo){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  min<-min(tabstdfr[["age"]],na.rm=TRUE)
  
  return(if(!is.finite(min)) {as.numeric(min)} else {0})  
}

getMinAgeStudentsByGroupByGender<-function(groupNo, gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$sex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  min<-min(tabstdfr[["age"]],na.rm=TRUE)
  return(if(is.infinite(min)) {0} else {as.numeric(min)})  
}

getMaxAgeStudentsByGroup<-function(groupNo){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  max<-max(tabstdfr[["age"]],na.rm=TRUE)
  return(if(is.infinite(max)) {0} else {as.numeric(max)})  
}

getMaxAgeStudentsByGroupByGender<-function(groupNo, gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$sex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)

  max<-max(tabstdfr[["age"]],na.rm=TRUE)
  return(if(is.infinite(max)) {0} else {as.numeric(max)})  
}


getSDAgeStudentsByGroup<-function(groupNo){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(sd(tabstdfr[["age"]],na.rm=TRUE)))  
}

getSDAgeStudentsByGroupByGender<-function(groupNo, gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==1,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$stud==groupNo,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$sex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  return(as.numeric(sd(tabstdfr[["age"]], na.rm=TRUE)))  
}


getNoOfTeachers<-function(){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(NROW(tabstdfr[["no"]])-1))  
}

getNoOfTeachersByGender<-function(gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$tsex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(NROW(tabstdfr[["no"]])-1))  
}

getAvgAgeTeachers<-function(){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(mean(tabstdfr[["tyea"]],na.rm=TRUE)))  
}

getAvgAgeTeachersByGender<-function(gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$tsex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(mean(tabstdfr[["tyea"]],na.rm=TRUE)))  
}

getMinAgeTeachers<-function(){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(min(tabstdfr[["tyea"]],na.rm=TRUE)))  
}

getMinAgeTeachersByGender<-function(gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$tsex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(min(tabstdfr[["tyea"]],na.rm=TRUE)))  
}

getMaxAgeTeachers<-function(){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(max(tabstdfr[["tyea"]],na.rm=TRUE)))  
}

getMaxAgeTeachersByGender<-function(gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$tsex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(max(tabstdfr[["tyea"]],na.rm=TRUE)))  
}


getSDAgeTeachers<-function(groupNo){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(sd(tabstdfr[["tyea"]],na.rm=TRUE)))  
}

getSDAgeTeachersByGender<-function(gender){
  tabstexcelfilt<-tabstexcel[tabstexcel$resp==2,]
  tabstexcelfilt<-tabstexcelfilt[tabstexcelfilt$tsex==gender,]
  tabstdfr<-data.frame(tabstexcelfilt)
  
  return(as.numeric(sd(tabstdfr[["tyea"]],na.rm=TRUE)))  
}

getYearsofTeaching<-function(code){
  res<-""
  if (is.na(code) || is.infinite(code)) {res<-""}
  else if (code < 2) {res<-"0-3"}
  else if (code >= 2 && code < 3) {res<-"4-6"}
  else if (code>=3) {res<-"more than 6"}
  else {res<-paste("Received code", code, sep=" ")}
  
  return(res)
}